#include <iostream>
#include <iomanip>
#include <vector>
using namespace std;

struct point {
    double x, y;
    point(double a, double b) {
        x = a;
        y = b;
    }
    point operator+(point other) {
        return point(this->x + other.x, this->y + other.y);
    }
};

struct line {
    double a, b, c;
    line(point f, point s) {
        a = f.y - s.y;
        b = s.x - f.x;
        c = f.x * s.y - f.y * s.x;
    }
    double f(point p) {
        return a * p.x + b * p.y + c;
    }
};

bool parallel(line f, line s) {
    return (f.a * s.b - f.b * s.a == 0);
}

point intersect(line f, line s) {
    if (parallel(f, s)) {
        return point(-228e6, -228e6);
    }
    return point((f.b * s.c - f.c * s.b) / (f.a * s.b - f.b * s.a),
                 (f.c * s.a - f.a * s.c) / (f.a * s.b - f.b * s.a));
}

double k(line l, point p) {
    if (l.b == 0) {
        return p.y;
    }
    return p.x;
}

int main() {
    int n;
    cin >> n;
    for (int i = 0; i < n; i++) {
        double ax1, ay1, ax2, ay2;
        double bx1, by1, bx2, by2;
        double vx, vy;
        cin >> ax1 >> ay1 >> ax2 >> ay2;
        cin >> bx1 >> by1 >> bx2 >> by2;
        cin >> vx >> vy;

        point a1(ax1, ay1), a2(ax2, ay2), b1(bx1, by1), b2(bx2, by2);
        point v(vx, vy);

        point d1 = a1 + v, d2 = a2 + v;

        line w1(a1, d1), w2(a2, d2), s1(a1, a2), s2(b1, b2);

        if (parallel(s2, w1)) {
            //cout << w1.f(b1) << " " << w2.f(b1) << endl;
            if (w1.f(b1) * w2.f(b1) > 0) {
                cout << "No" << endl;
            } else {
                cout << "Yes" << endl;
            }
            continue;
        }

        point p1 = intersect(w1, s2), p2 = intersect(w2, s2);

        //cout << s1.f(d1) << " " << s1.f(p1) << "   " << s1.f(d2) << " " << s1.f(p2) << endl;
        if (s1.f(d1) * s1.f(p1) < 0 && s1.f(d2) * s1.f(p2) < 0) {
            cout << "No" << endl;
            continue;
        }

        if (s1.f(d1) * s1.f(p1) < 0) {
            p1 = intersect(s2, s1);
        }
        if (s1.f(d2) * s1.f(p2) < 0) {
            p2 = intersect(s2, s1);
        }

        double h1 = k(s2, p1), h2 = k(s2, p2), g1 = k(s2, b1), g2 = k(s2, b2);
        if (h1 > h2) {
            double temp = h1;
            h1 = h2;
            h2 = temp;
        }
        if (g1 > g2) {
            double temp = g1;
            g1 = g2;
            g2 = temp;
        }

        //cout << h1 << " " << h2 << "   " << g1 << " " << g2 << endl;

        if (g2 < h1 || h2 < g1) {
            cout << "No" << endl;
        } else {
            cout << "Yes" << endl;
        }

    }
    return 0;
}
