#include <cstdio>
#include <cassert>
#include <iostream>
#include <cmath>
#include <vector>
#include <functional>

using namespace std;
const int INF = int(1.01e9);

const int step[4][3][2] = {{{1, 1}, {0, 1}, {-1, 1}},
                           {{-1, 1}, {-1, 0}, {-1, -1}},
                           {{-1, -1}, {0, -1}, {1, -1}},
                           {{1, -1}, {1, 0}, {1, 1}}};

void back_cor(int x, int y, int shift_y, int& xx, int& yy) {
    yy = (x + y - shift_y) / 2;
    xx = (x - y + shift_y) / 2;
}

int global_answer = 0;

vector<vector<bool>> solve(const vector<vector<char>>& board) {
    int n = board.size();
    int m = board[0].size();
    int sx =  n + m - 2 + 1;
    int shift_y = n;
    vector<string> rt(sx + 1, string(sx + 2, '.'));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (board[i][j] != 0) {
                rt[i + j][j - i + shift_y] = board[i][j];
            }
        }
    }
    vector<vector<int>> dp(sx + 1, vector<int>(sx + 1));
    vector<vector<int>> par(sx + 1, vector<int>(sx + 1));

    for (int i = 0; i < sx; i++) {
        int cntR = 0;
        int cntL = 0;
        for (int j = 0; j <= sx; j++) {
            if (rt[i][j] == 'R') {
                cntR++;
            }
            if (rt[i + 1][j + 1] == 'L') {
                cntL++;
            }
        }
        int best_score = INF;
        int where = -1;
        if (i == 0) {
            best_score = 0;
        }
        int curL = 0;
        int curR = 0;
        for (int j = sx; j >= 0; j--) {
            if (i > 0 && dp[i - 1][j] < best_score) {
                best_score = dp[i - 1][j];
                where = j;
            }
            dp[i][j] = best_score + (cntR - curR) + curL;
            par[i][j] = where;

            if (rt[i + 1][j + 1] == 'L') {
                curL++;
            }
            if (rt[i][j] == 'R') {
                curR++;
            }
        }
    }
    vector<vector<bool>> ret(n, vector<bool>(m, 0));

    int pos = 0;
    int res1 = dp[sx - 1][pos];
    for (int i = sx - 1; i >= 0; i--) {
        int prev = par[i][pos];
        for (int j = (i + shift_y) % 2; j <= pos; j += 2) {
            if (rt[i][j] == 'R') {
                int x, y;
                back_cor(i, j, shift_y, x, y);
                ret[x][y] = true;
            }
        }
        int st = pos + 1;
        if ((i + st + shift_y) % 2 == 1) {
            st++;
        }
        for (int j = st; j <= sx; j += 2) {
           if (rt[i + 1][j + 1] == 'L')  {
               int x, y;
               back_cor(i + 1, j + 1, shift_y, x, y);
               ret[x][y] = true;
           }
        }
        pos = prev;
    }
    global_answer += res1;
    return ret;
}

template<typename T>
vector<vector<T>> flip(const vector<vector<T>>& a) {
    int n = a.size();
    int m = a[0].size();
    vector<vector<T>> ret(m, vector<T>(n));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            ret[j][i] = a[i][j];
        }
    }
    return ret;
}

int n, m;

bool check (int x, int y) {
    return 0 <= x && x < n && 0 <= y && y < m;
};

vector<vector<char>> color;

void dfs(int x, int y, int id) {
    color[x][y] = id;
    for (int i = 0; i < 3; i++) {
        int xx = x + step[id][i][0];
        int yy = y + step[id][i][1];
        if (check(xx, yy) && color[xx][yy] == -1) {
            dfs(xx, yy, id);
        }
    }
};

void first_call_dfs(int x, int y, int id) {
    int xx = x + step[id][1][0];
    int yy = y + step[id][1][1];
    if (check(xx, yy) && color[xx][yy] == -1) {
        dfs(xx, yy, id);
    }
}

const int BUF_SIZE = 10000;
char s_buf[BUF_SIZE];

int main() {
#define TASK "A"
#ifdef HOME
    assert(freopen(TASK".in", "r", stdin));
    assert(freopen(TASK".out", "w", stdout));
#endif
    scanf("%d%d\n", &n, &m);
    vector<vector<char>> s(n);
    for (int i = 0; i < n; i++) {
        fgets(s_buf, BUF_SIZE, stdin);
        s[i] = vector<char>(s_buf, s_buf + m);
    }

    vector<vector<bool>> blocked[2];
    for (int tt = 0; tt < 2; tt++) {
        vector<vector<char>> tmp(n, vector<char>(m));
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (tt == 0) {
                    if (s[i][j] == 'R') {
                        tmp[i][j] = 'R';
                    }
                    if (s[i][j] == 'L') {
                        tmp[i][j] = 'L';
                    }
                }
                else {
                    if (s[i][j] == 'D') {
                        tmp[i][j] = 'R';
                    }
                    if (s[i][j] == 'U')  {
                        tmp[i][j] = 'L';
                    }
                }
            }
        }
        blocked[tt] = solve(tmp);
        s = flip(s);
        swap(n, m);
    }
    blocked[1] = flip(blocked[1]);
    vector<string> answer(n, string(m, '.'));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (s[i][j] != '.' && !blocked[0][i][j] && !blocked[1][i][j]) {
                answer[i][j] = s[i][j];
            }
        }
    }

    string code = "RULD";
    for (int tt = 0; tt < 2; tt++) {
        color.assign(n, vector<char>(m, -1));
        int up, down;
        if (tt == 0) {
            up = 1;
            down = 3;
        }
        else {
            up = 0;
            down = 2;
        }
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (s[i][j] == code[up] && !blocked[tt ^ 1][i][j]) {
                    first_call_dfs(i, j, up);
                }
                if (s[i][j] == code[down]&& !blocked[tt ^ 1][i][j]) {
                    first_call_dfs(i, j, down);
                }
            }
        }

        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (blocked[tt][i][j]) {
                    if (color[i][j] == -1 || color[i][j] == down) {
                        first_call_dfs(i, j, down);
                        answer[i][j] = code[down];
                    } else {
                        assert(color[i][j] == up);
                        answer[i][j] = code[up];
                    }
                }
            }
        }
    }
    for (int i = 0; i < n; i++) {
        cout << answer[i] << "\n";
    }
    return 0;
}


