import sys
import math


class Line:
    def __init__(self, a, b, c):
        self.a = a
        self.b = b
        self.c = c


def line_with_two_point(x1, y1, x2, y2):
    a = y1 - y2
    b = x2 - x1
    c = -a * x1 - b * y1
    return Line(a, b, c)


def hate(x, y, line):
    return abs((line.a * x + line.b * y + line.c) / math.sqrt(line.a ** 2 + line.b ** 2))


EPS = 1e-5


def between(line1, line2, height, x, y):
    return abs(height - hate(x, y, line1) - hate(x, y, line2)) < EPS


def f(line, x, y):
    return line.a * x + line.b * y + line.c


def check(line, x, y, x0, y0):
    return f(line, x, y) * f(line, x0, y0) >= 0


def length(x1, y1, x2, y2):
    return math.sqrt((x1 - x2) ** 2 + (y1 - y2) ** 2)


def belong_segment(x1, y1, x2, y2, x3, y3):
    return abs(length(x1, y1, x2, y2) - length(x1, y1, x3, y3) - length(x2, y2, x3, y3)) < EPS


def belong(x1, y1, x2, y2, x3, y3, x4, y4, line3):
    line1 = line_with_two_point(x1, y1, x2, y2)
    line2 = line_with_two_point(x3, y3, x4, y4)
    d = line1.b * line2.c - line2.b * line1.c
    if abs(d)<EPS:
        return False
    if abs((line1.a + (line1.b * (line2.a * line1.c - line1.a * line2.c)) / (d))) < EPS:
        return False
    x = -line1.c / (line1.a + (line1.b * (line2.a * line1.c - line1.a * line2.c)) / (d))

    y = x * (line2.a * line1.c - line1.a * line2.c) / d
    return check(line3, x4, y4, x, y) and belong_segment(x1, y1, x2, y2, x, y)


def main():
    n = int(sys.stdin.readline())
    for i in range(n):
        ax1, ay1, ax2, ay2, bx1, by1, bx2, by2, ux, uy = map(float, sys.stdin.readline().split())
        cx = ax1 + ux
        cy = ay1 + uy
        dx = ax2 + ux
        dy = ay2 + uy
        line1 = line_with_two_point(ax1, ay1, cx, cy)
        line2 = line_with_two_point(ax2, ay2, dx, dy)
        height = hate(ax1, ay1, line2)
        new_line = line_with_two_point(ax1, ay1, ax2, ay2)
        if between(line1, line2, height, bx1, by1) and check(new_line, bx1, by1, cx, cy):
            print("Yes")
            continue
        if between(line1, line2, height, bx2, by2) and check(new_line, bx2, by2, cx, cy):
            print("Yes")
            continue
        if belong(bx1,by1,bx2,by2,ax1,ay1,cx,cy, new_line):
            print("Yes")
            continue


        print("No")


main()
