#pragma GCC optimize("Ofast,no-stack-protector,unroll-loops,fast-math")
#pragma GCC target("sse,sse2,sse3,ssse3,sse4.1,sse4.2,popcnt,tune=native")
#pragma GCC target("avx,avx2")

#include "bits/stdc++.h"

using namespace std;

typedef long long ll;
typedef long double ld;

ld dist(ld a, ld b)
{
    return sqrtl(a * a + b * b);
}

struct Point
{
    ld x, y;
    Point () {};
    Point (ld x, ld y) : x(x), y(y) {}
    ld distanceTo(Point other)
    {
        return dist(other.x - x, other.y - y);
    }
    bool operator<(Point other)
    {
        if (x != other.x)
            return x < other.x;
    }
};

istream& operator>>(istream& in, Point&p)
{
    in >> p.x >> p.y;
    return in;
}

struct Vector
{
    ld x, y;
    Vector(ld x, ld y) : x(x), y (y) {}
    Vector(Point a, Point b)
    {
        x = b.x - a.x;
        y = b.y - a.y;
    }
    Vector toOrthogonal()
    {
        return {-y, x};
    }
    Vector toReverse()
    {
        return {-x, -y};
    }
    ld cross(Vector other)
    {
        return x * other.y - y * other.x;
    }
    ld dot(Vector other)
    {
        return x * other.x + y * other.y;
    }
    bool isNullVector()
    {
        return !x && !y;
    }
    bool isCodirectionalTo(Vector other)
    {
        return cross(other) == 0 && dot(other) >= 0;
    }
};

Point operator+(Vector v, Point p)
{
    return {p.x + v.x, p.y + v.y};
}

struct Line
{
    ld a, b, c;
    Line(Point _a, Point _b) {
        a = _b.y - _a.y;
        b = _a.x - _b.x;
        c = _a.y * (_b.x - _a.x) - _a.x * (_b.y - _a.y);
    }
    Line (Point _a, Vector _codir) : Line(_a, _codir + _a) {}
    Vector normalVector()
    {
        return {a, b};
    }
    bool isParallelTo(Line other)
    {
        return normalVector().cross(other.normalVector()) == 0;
    }
    Point intersect(Line other)
    {
        ld opr = (a * other.b) - (b * other.a);
        ld x = (-c * other.b) - (b * -other.c);
        ld y = (a * -other.c) - (-c * other.a);
        return {x / opr, y / opr};
    }
};

struct Segment
{
    Point a, b;
    Segment() {}
    Segment(Point _a, Point _b)
    {
        if (_b < _a)
            swap(_a, _b);
        a = _a, b = _b;
    }
    ld length()
    {
        return a.distanceTo(b);
    }
    bool contains(Point p)
    {
        Vector ap(a, p), bp(b, p), ab(a, b);
        return ab.isCodirectionalTo(ap) && ab.toReverse().isCodirectionalTo(bp);
    }
    bool doIntersect(Segment other)
    {
        Point c = other.a, d = other.b;
        Vector ab(a, b), ac(a, c), ad(a, d), bc(b, c), cd(c, d);
        ld cd_ca = cd.cross(ac.toReverse()),
        cd_cb = cd.cross(bc.toReverse()),
        ab_ac = ab.cross(ac),
        ab_ad = ab.cross(ad);
        if (cd_ca || cd_cb || ab_ac || ab_ad)
        {
            return cd_ca * cd_cb <= 0 && ab_ac * ab_ad <= 0;
        }
        return other.contains(a) || other.contains(b) || contains(c) || contains(d);
    }
};

int main()
{
    int n;
    cin >> n;
    while(n--) {
        Point a, b, c, d;
        cin >> a >> b >> c >> d;
        ld vx, vy;
        cin >> vx >> vy;
        Vector v(vx, vy);
        if (v.isNullVector() || Segment(a, b).doIntersect({c, d})) {
            cout << "Yes\n";
            continue;
        }
        Line av(a, v);
        Line cd(c, d);
        if (av.isParallelTo(cd))
        {
            if (Line(a, b).isParallelTo({c, d}))
            {
                bool res = Vector(b, c).isCodirectionalTo(v);
                if (res)
                {
                    cout << "Yes\n";
                } else {
                    cout << "No\n";
                }
                continue;
            }
            bool res = Vector(a, c).cross(v) * Vector(b, c).cross(v) <= 0;
            if (res)
            {
                cout << "No\n";
            } else {
                cout << "Yes\n";
            }
            continue;
        }
        Point as = av.intersect(cd);
        Point bs = Line(b, v).intersect(cd);
        if (!Vector(a, as).isCodirectionalTo(v))
        {
            cout << "No\n";
            continue;
        }
        bool res = Segment(as, bs).doIntersect({c, d});
        if (!res)
        {
            cout << "No\n";
        } else {
            cout << "Yes\n";
        }
    }
}