#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <cmath>

using namespace std;

typedef long long ll;
typedef long double ld;

const ld EPS = 1e-6;

struct Point {
	ld x, y;
	Point() : x(0), y(0) {}
	Point(ld a, ld b) : x(a), y(b) {}
};

istream& operator >> (istream& is, Point& p) {
	is >> p.x >> p.y;
	return is;
}

struct Vect {
	ld x, y;
	Vect(Point a, Point b) : x(b.x - a.x), y(b.y - a.y) {}
	Vect(ld a, ld b) : x(a), y(b) {}
	Vect() : x(0), y(0) {}
};

Point operator + (Point a, Vect b) {
	return Point(a.x + b.x, a.y + b.y);
}

ld range(Point a, Point b) {
	return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

struct Line {
	ld A, B, C;
	Line(Point a, Point b) : A(a.y - b.y), B(b.x - a.x), C(-A * a.x - B * a.y) {}

	friend bool operator == (Line a, Line b) {
		return b.A * a.B * a.C == a.A * b.B * a.C && a.A * b.B * a.C == a.A * a.B * b.C;
	}
};

bool In(Point a, Point b, Point p) {
	return abs(range(a, b) - range(a, p) - range(p, b)) < EPS;
}

bool eq(ld a, ld b) {
	return (a > 0 && b > 0) || (a < 0 && b < 0);
}

bool Check(Point fgh, Line a, Line b, Point f, Point s, Vect c) {
	if (a == b) return true;
	if (a.A * b.B - b.A * a.B == 0) return false;
	Point ans;
	ans.x = -(a.C * b.B - b.C * a.B) / (a.A * b.B - b.A * a.B);
	ans.y = -(a.A * b.C - b.A * a.C) / (a.A * b.B - b.A * a.B);
	ld rofl1 = Vect(fgh, ans).x, rofl2 = Vect(fgh, ans).y;
	if (!eq(rofl1, c.x) || !eq(rofl2, c.y)) return false;
	return In(f, s, ans);
}

bool parl(Line a, Line b) {
	return a.A * b.B - b.A * a.B == 0;
}


int main() {

	//fstream cin("input.txt");
	//ofstream cout("output.txt");

	ll a, b;
	cin >> a >> b;
	if (a == b) {
		cout << "Stable" << endl;
		cout << 0 << endl;
		return 0;
	}
	ll r1 = a % 9, r2 = b % 9;
	ll cur = 10;
	vector<pair<char, int>> ans;
	if (a > 10) {
		while (a > cur) {
			cur *= 10L;
		}
		ll dif = (cur - a) / 9;
		if ((cur - a) % 9 > 0) {
			dif++;
		}
		ans.push_back({ '+', dif });
		ans.push_back({ '-', 1 });
		r1 = (r1 - 1 + 9) % 9;
	}
	while (r1 != r2) {
		if (r1 + 9 >= 10) {
			ans.push_back({ '+', 1 });
			ans.push_back({ '-', 1 });
			r1 = (r1 - 1 + 9) % 9;
		}
		else {
			ans.push_back({ '+', 2 });
			ans.push_back({ '-', 1 });
			r1 = 8;
		}
	}
	b -= r2;
	if (b / 9 > 0) {
		ans.push_back({ '+', b / 9 });
	}
	cout << "Stable" << endl;
	cout << ans.size() << endl;
	for (int i = 0; i < ans.size(); i++) {
		cout << ans[i].first << " " << ans[i].second << endl;
	}
}