#include <bits/stdc++.h>

#define all(a) (a).begin(), (a).end()
#define rall(a) (a).rbegin(), (a).rend()

using namespace std;
typedef long long ll;
typedef long double ld;

void boot_up() {
    #ifdef LOCAL
        freopen("input.txt", "r", stdin);
        freopen("output.txt", "w", stdout);
    #endif // LOCAL

    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
}

const ld EPS = (ld)1e-9;

struct Vec {
    ld x, y;

    Vec() : x(0), y(0) {
    }

    Vec(ld _x, ld _y) : x(_x), y(_y) {
    }

    Vec operator + (const Vec & other) {
        return {x + other.x, y + other.y};
    }

    Vec operator - (const Vec & other) {
        return {x - other.x, y - other.y};
    }

    ld operator % (const Vec & other) {
        return x * other.y - y * other.x;
    }

    ld operator ^ (const Vec & other) {
        return x * other.x + y * other.y;
    }

    Vec operator * (const ld & k) {
        return {k * x, k * y};
    }

    ld len() {
        return hypot(x, y);
    }

    void norm() {
        ld len1 = this->len();

        x /= len1;
        y /= len1;
    }
};

struct Line {
    ld a, b, c;

    Line(Vec & v1, Vec & v2) {
        a = v2.y - v1.y;
        b = v1.x - v2.x;
        c = -a * v1.x - b * v1.y;
    }

    ld value(Vec & v) {
        return v.x * a + v.y * b + c;
    }
};

int sign(ld x){
    if (x > EPS) return 1;
    if (x < -EPS) return -1;
    return 0;
}

bool is_dot_in_ray(Vec& a, Vec& b, Vec& x){
    Vec ab = b - a;
    Vec ax = x - a;
    return ((sign(ab % ax) == 0) && (sign(ab ^ ax) != -1));
}

bool is_dot_in_seg(Vec& a, Vec& b, Vec& pt){
    return (is_dot_in_ray(a, b, pt) && is_dot_in_ray(b, a, pt));
}

bool is_intersect(Vec& a, Vec& b, Vec& c, Vec& d) {
    if (is_dot_in_seg(a, b, c) || is_dot_in_seg(a, b, d) || is_dot_in_seg(c, d, a) || is_dot_in_seg(c, d, b)) return true;
    Vec ac = c - a, ad = d - a, ca = a - c, cb = b - c, ab = b - a, cd = d - c;
    return (sign((ac % ab)) == sign((ab % ad))) && (sign((ca % cd)) == sign((cd % cb)));
}

bool belongs(Vec & x, Vec & a, Vec & o, Vec & b) {
    Vec oa = a - o;
    Vec ox = x - o;
    Vec ob = b - o;
  //  cout << oa.x << " " << oa.y << " " << ob.x << " " << ob.y << " " << ox.x << " " << ox.y << '\n';

    if (is_dot_in_seg(x, o, a) || is_dot_in_seg(x, o, b)) return true;
    int sgn1 = sign(oa % ox), sgn2 = sign(ox % ob), sgn3 = sign(oa % ob);
    //cout << sgn1 << " " << sgn2 << " " << sgn3 << '\n';

    return (sgn3 != 0) && (sgn1 == sgn2) && (sgn2 == sgn3);
}

const ld INF =(ld)1e5;

int main() {
    boot_up();

    int n;
    cin >> n;

    for (int i = 0; i < n; ++i) {
        Vec a, b, c, d;
        Vec v;

        cin >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y >> d.x >> d.y;
        cin >> v.x >> v.y;

        Vec tmp = v;
        tmp.norm();
        tmp = (tmp * INF);

        Vec e = a + tmp;
        Vec f = b + tmp;
        //cout << e.x << " " << e.y << " " << f.x << " " << f.y << '\n';

        Line l1(a, e);
        Line l2(b, f);
        Line l3(c, d);

        if (is_intersect(c, d, a, e) || is_intersect(c, d, b, f)) {
            cout << "Yes\n";
        }
        else {
            if ((belongs(c, e, a, b) && belongs(c, f, b, a)) && (belongs(d, e, a, b) && belongs(d, f, b, a))) {
                    cout << "Yes\n";
                }
                else {
                    cout << "No\n";
                }
        }
    }

    return 0;
}
